/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.web.skin.UIZoneItem');

/**
 * Register the html element zoneName in the document doc as a zone. If empty do some additional graphic.
 * @param {HTMLWindow} win The window where to work in
 * @param {String} pageId The page identifier 
 * @param {boolean} modifiable Is the zone modifiable ?
 * @param {String} zoneName The id of the html element surrounding the zone
 * @param {String} zoneItemHTMLId The id of the html element surrounding the zone
 * @param {String} zoneItemId The id of the repository zone item
 * @param {String} contentName If the zone item has a content, the content name is here
 * @param {String} contentTypeOrServiceId If the zone item has a content, contains the content type ID. If the zone item has a service, the service id.
 * @param {String} label The label of type of content
 * @param {String} description The description of type of content 
 * @param {String} smallIcon The path to the small icon
 * @param {String} mediumIcon The path to the medium icon
 * @param {String} largeIcon The path to the large icon
 */
org.ametys.web.skin.UIZoneItem.register = function(win, pageId, modifiable, zoneName, zoneItemHTMLId, zoneItemId, contentName, contentTypeOrServiceId, label, description, smallIcon, mediumIcon, largeIcon)
{
	var doc = win.document;
	if (doc.zoneItems == null){ doc.zoneItems = []; }

	doc.zoneItems.push({zoneName : zoneName, zoneItemHTMLId: zoneItemHTMLId, zoneItemId: zoneItemId});

	
	var div = doc.getElementById("ametys-cms-zone-" + zoneName + "-item-" + zoneItemHTMLId);
	div.className += " ametys-cms-zone-item";
	div.setAttribute("zoneitem", zoneItemId);
	div.setAttribute("zoneitem-type", contentName != "" ? 'content' : 'service');
	div.setAttribute("zoneitem-type-id", contentTypeOrServiceId);
	
	var pageTool = parent.org.ametys.uitool.ToolsManager.getInstance().getTool(doc._pageId);
	org.ametys.web.skin.UIZoneItem.highlight(win, zoneName, zoneItemHTMLId, zoneItemId, pageTool._lastZoneItemId == zoneItemId, true);
	

	var img = doc.createElement("img");
	img.className = "ametys-cms-zone-item-grabber";
	img.onclick = parent.org.ametys.web.skin.UIZoneItem.highlight.createDelegate(parent.org.ametys.web.skin.UIZoneItem.highlight, [win, zoneName, zoneItemHTMLId, zoneItemId]);
	img.title = label 
			+ (contentName != "" ? (" (" + contentName + ")") : "")
			+ " : "
			+ description;
	if (smallIcon != null && smallIcon != "")
	{
		img.src = context.contextPath + smallIcon;
	}
	else
	{
		img.src = getPluginResourcesUrl("web") + "/img/skin/zone_error_16.png";
	}

	div.insertBefore(img, div.firstChild);
	
	if (modifiable)
	{
		org.ametys.web.skin.UIZoneItem.makesDraggable(win, pageId, div, img, label, contentName, zoneItemId, contentTypeOrServiceId);
	}
}

if (!org.ametys.web.skin.UIZoneItem.makesDraggable)
{
	org.ametys.web.skin.UIZoneItem.makesDraggable = function(win, pageId, div, img, label, contentName, zoneItemId, contentTypeOrServiceId)
	{
		// Default behavior : Nothing to do
		// Has to be overriden
	}
}

/**
 * Graphically highlight a zone
 * @param {HTMLWindow} win The window of the page
 * @param {String} zoneName The id of the html element (div) of the zone to highlight in the document
 * @param {String} zoneItemHTMLId The id of the html element surrounding the zone
 * @param {String} zoneItemId The id of the repository zone item
 * @param {boolean} on Set to true to highlight or false to set normal 
 * @param {boolean} noEvent true to do not send events. false is default
 */
org.ametys.web.skin.UIZoneItem.highlight = function(win, zoneName, zoneItemHTMLId, zoneItemId, on, noEvent) 
{
	var doc = win.document;
	var div = doc.getElementById("ametys-cms-zone-" + zoneName + "-item-" + zoneItemHTMLId);

	if (on == null)
	{
		on = !div.highlightState;
	}
	
	if (on)
	{
		for (var i=0; i < doc.zones.length; i++)
		{
			var aZoneName = doc.zones[i];
			org.ametys.web.skin.UIZone.highlight(win, aZoneName, false, true);
		}

		// switch off other zones
		for (var i=0; i < doc.zoneItems.length; i++)
		{
			var aZoneInfo = doc.zoneItems[i];
			if (aZoneInfo.zoneItemId != zoneItemId)
			{
				org.ametys.web.skin.UIZoneItem.highlight(win, aZoneInfo.zoneName, aZoneInfo.zoneItemHTMLId, aZoneInfo.zoneItemId, false, true);
			}
		}
	}
	
	div.highlightState = on;

	if (on)
	{
		if (div.className.indexOf('ametys-cms-zone-item-selected') == -1)
		{
			div.className += " ametys-cms-zone-item-selected";
		}
	}
	else
	{
		div.className = div.className.replace(new RegExp('(?:^|\\s+)ametys-cms-zone-item-selected(?:\\s+|$)', "g"), " ");
	}
	
	if (noEvent != true)
	{
		org.ametys.web.skin.UIZoneItem._select.defer(1, org.ametys.web.skin.UIZone._select, [win, on ? zoneItemId : null]);
	}
}

org.ametys.web.skin.UIZoneItem._select = function(win, zoneItemId)
{
	if (typeof win.onZoneSelected == "function")
	{
		win.onZoneSelected(null, zoneItemId, zoneItemId != null ? win.$j(win.document.body).find("div.ametys-cms-zone-item-selected").parent("div.ametys-cms-zone").outerWidth() : null);
	}
	else
	{
		org.ametys.web.skin.UIZoneItem._select.defer(5, org.ametys.web.skin.UIZoneItem._select, [win, zoneItemId]);
	}
}